import { useCallback, useEffect, useRef } from 'react';
export default function useTimeoutFn(fn, ms) {
    if (ms === void 0) { ms = 0; }
    var ready = useRef(false);
    var timeout = useRef();
    var isReady = useCallback(function () { return ready.current; }, []);
    var set = useCallback(function () {
        ready.current = false;
        timeout.current = setTimeout(function () {
            ready.current = true;
            fn();
        }, ms);
    }, [ms, fn]);
    var clear = useCallback(function () {
        ready.current = null;
        timeout.current && clearTimeout(timeout.current);
    }, []);
    useEffect(function () {
        set();
        return clear;
    }, [ms]);
    return [isReady, clear, set];
}
